package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````6!4``#0```!0@0````0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````:'T`
M`&A]```%```````!``$```#,?0``S'T!`,Q]`0!P`@``G!(```8```````$`
M`@```-1]``#4?0$`U'T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3,?0``S'T!`,Q]`0`T`@``-`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$P````(````"```
M``&0$``E0`2`*(`0!:"&4(2``0``"R`$C3B`$D&*!`@(3````$T```!1````
M5@```%<```!>````7P```&``````````8@```&,`````````9````&4```!H
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!6.^7>;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FH:GE"_VE<;H^#[20``````````
M````````````````#!`````````#``<```````"``0```````P`1``$`````
M`````````!(````)```````````````1````[`$`````````````$0```(@!
M`````````````!(````0```````````````2````Q0$`````````````$@``
M`!@``````````````!(````?```````````````2````^0$`````````````
M$@```-$!`````````````!(````H```````````````@````'P,`````````
M````(0```$```````````````!(```!&```````````````2````30``````
M````````$@```,X"`````````````!(```#T`@`````````````2````5```
M````````````$@```#8"`````````````!(```!;```````````````2````
MO`(`````````````$@```&(``````````````!(```!J```````````````2
M````I0(`````````````$@```'(``````````````!(```![````````````
M```@````Y@(`````````````$@```)<``````````````!(```"<````````
M```````2````"@(`````````````$0```,,"`````````````!(```!C`@``
M```````````2````HP``````````````$@```%4"`````````````!(```!C
M`P`````````````2````'@,`````````````$0```(<"`````````````!(`
M```+`P`````````````2````%0(`````````````$@```"`#````````````
M`!$```"J```````````````2````W@(`````````````$@```+,`````````
M`````!$```"6`0`````````````2````Q0``````````````(@```-0`````
M`````````"````#J```````````````2`````P,`````````````$@```',"
M`````````````!(```#O```````````````2````]0``````````````(```
M`+`"`````````````!(````/`0`````````````2````M@$`````````````
M$@```!0!`````````````!(```"5`@`````````````2````&@$`````````
M````$@```*4!`````````````!(````H`0`````````````2````.0$`````
M````````$@```#$"`````````````!(```!"`@`````````````2````/P$`
M````````````$@```'P"`````````````!(```#M`@`````````````2````
M3@$`````````````$@```-8"`````````````!(```!B`0`````````````2
M````+`(`````````````$@```&D!`````````````!(```!P`0``````````
M```2````'0,`````````````(0```($!`````````````!(```!C!```:)`!
M```````0`!(`&`,``/P2``!<`@``$@`)`.8!``#4/0``!````!(`"@"E`P``
MW"4```0'```2``D`<P0``%0O``!8````$@`)`((#```8'P``!````!(`"0`7
M!```#!````0````2``<`R`,``.`L``!T`@``$@`)`!T$```\@`$``````!``
M$@!+!```'!\``#`"```2``D```0``#R``0``````$``2`),#```H)0``M```
M`!(`"0"R`P``_!P``%P````2``D`N@,``*@D``!H````$@`)`-X#``!8.P``
M1`$``!(`"0#S`P``3"$``!P````2``D`#`0``&B0`0``````$``2`&X$``!H
MD`$``````!``$@!(`P``?!4``&0````2``D`*P0``&@A```(`0``$@`)`.D#
M```X@`$`!````!$`$0!$!```/(`!```````0`!$`!00``%@5````````$@`)
M`!0$```(.P``4````!(`"0!1`P``$"4``!@````2``D`;`,``,0=``!4`0``
M$@`)`%@$``"</```.`$``!(`"0!B!```:)`!```````0`!(`-P0``'`B```X
M`@``$@`)``!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!S;G!R:6YT
M9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`<W1R8VUP
M`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N8VUP`&-L;W-E9&ER`%])5$U?
M9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'-T<G-T<@!S=')C:'(`<F5A
M9&QI;FL`7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?9FEN86QI>F4`7U]R96=I
M<W1E<E]F<F%M95]I;F9O`&5X:70`8VQO<V4`7TE435]R96=I<W1E<E1-0VQO
M;F5486)L90!R96%D`')M9&ER`%]?<W1A=%]T:6UE-C0`7U]E<G)N;U]L;V-A
M=&EO;@!M:V1I<@!?7VQS=&%T7W1I;64V-`!P=&AR96%D7V=E='-P96-I9FEC
M`&UE;6-P>0!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S
M>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?
M8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%]F
M:6YI`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`
M4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A
M;&QO8P!R96%D9&ER`'-P<FEN=&8`<W1R;F-P>0!S=')D=7``<W1R=&]K`'!T
M:')E861?871F;W)K`&9P<FEN=&8`7U]L:6)C7W-T87)T7VUA:6X`7U]?96YV
M:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"UA<FUH9BYS;RXQ`%]S=&%R=%]C
M`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C=7)R96YT7V5X96-?
M<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S971U<%]L:6)P871H`'!A<E]M
M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!
M4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L`'!A<E]B87-E;F%M90!?7V)S
M<U]S=&%R=`!?7V5N9%]?`'-H85]I;FET`%]?8G-S7W-T87)T7U\`<&%R7V1I
M<FYA;64`<&%R7VEN:71?96YV`%]E9&%T80!P87)?9FEN9'!R;V<`<VAA7V9I
M;F%L`%]?8G-S7V5N9%]?`%]E;F0`<&%R7V-L96%N=7``+W5S<B]L:6(O<&5R
M;#4O8V]R95]P97)L+T-/4D4`````S'T!`!<```#0?0$`%P```,!_`0`7````
MS'\!`!<```#8?P$`%P````"``0`7````"(`!`!<````,@`$`%P```!2``0`7
M````&(`!`!<````<@`$`%P```""``0`7````)(`!`!<````L@`$`%P```#"`
M`0`7````.(`!`!<```#$?P$`%00``,A_`0`5!0``T'\!`!4-``#4?P$`%1P`
M`-Q_`0`5(```X'\!`!4J``#D?P$`%2T``.A_`0`5+P``['\!`!4P``#P?P$`
M%34``/1_`0`5.@``^'\!`!4\``#\?P$`%4```-!^`0`6`P``U'X!`!8&``#8
M?@$`%@<``-Q^`0`6"```X'X!`!8)``#D?@$`%@H``.A^`0`6"P``['X!`!8,
M``#P?@$`%@T``/1^`0`6#P``^'X!`!80``#\?@$`%A$```!_`0`6$@``!'\!
M`!83```(?P$`%A0```Q_`0`6%0``$'\!`!86```4?P$`%A<``!A_`0`6&```
M''\!`!89```@?P$`%AH``"1_`0`6&P``*'\!`!8=```L?P$`%AX``#!_`0`6
M'P``-'\!`!8A```X?P$`%B(``#Q_`0`6(P``0'\!`!8D``!$?P$`%B4``$A_
M`0`6)P``3'\!`!8H``!0?P$`%BD``%1_`0`6*P``6'\!`!8L``!<?P$`%BX`
M`&!_`0`6+P``9'\!`!8P``!H?P$`%C$``&Q_`0`6,@``<'\!`!8S``!T?P$`
M%C0``'A_`0`6-@``?'\!`!8W``"`?P$`%C@``(1_`0`6.0``B'\!`!8[``",
M?P$`%CT``)!_`0`6/@``E'\!`!8_``"8?P$`%D$``)Q_`0`60@``H'\!`!9#
M``"D?P$`%D0``*A_`0`610``K'\!`!9&``"P?P$`%D<``+1_`0`62```N'\!
M`!9)``"\?P$`%DL```%`+>D!0+WH'O\OX03@+>4$X)_E#N"/X`CPON6<;@$`
M`,:/XA;*C.*<_KSE`,:/XA;*C.*4_KSE`,:/XA;*C.*,_KSE`,:/XA;*C.*$
M_KSE`,:/XA;*C.)\_KSE`,:/XA;*C.)T_KSE`,:/XA;*C.)L_KSE`,:/XA;*
MC.)D_KSE`,:/XA;*C.)<_KSE`,:/XA;*C.)4_KSE`,:/XA;*C.),_KSE`,:/
MXA;*C.)$_KSE`,:/XA;*C.(\_KSE`,:/XA;*C.(T_KSE`,:/XA;*C.(L_KSE
M`,:/XA;*C.(D_KSE`,:/XA;*C.(<_KSE`,:/XA;*C.(4_KSE`,:/XA;*C.(,
M_KSE`,:/XA;*C.($_KSE`,:/XA;*C.+\_;SE`,:/XA;*C.+T_;SE`,:/XA;*
MC.+L_;SE`,:/XA;*C.+D_;SE`,:/XA;*C.+<_;SE`,:/XA;*C.+4_;SE`,:/
MXA;*C.+,_;SE`,:/XA;*C.+$_;SE`,:/XA;*C.*\_;SE`,:/XA;*C.*T_;SE
M`,:/XA;*C.*L_;SE`,:/XA;*C.*D_;SE`,:/XA;*C.*<_;SE`,:/XA;*C.*4
M_;SE`,:/XA;*C.*,_;SE`,:/XA;*C.*$_;SE`,:/XA;*C.)\_;SE`,:/XA;*
MC.)T_;SE`,:/XA;*C.)L_;SE`,:/XA;*C.)D_;SE`,:/XA;*C.)<_;SE`,:/
MXA;*C.)4_;SE`,:/XA;*C.),_;SE`,:/XA;*C.)$_;SE`,:/XA;*C.(\_;SE
M`,:/XA;*C.(T_;SE`,:/XA;*C.(L_;SE`,:/XA;*C.(D_;SE`,:/XA;*C.(<
M_;SE`,:/XA;*C.(4_;SE`,:/XA;*C.(,_;SE`,:/XA;*C.($_;SE`,:/XA;*
MC.+\_+SE`,:/XA;*C.+T_+SE`,:/XA;*C.+L_+SE`,:/XA;*C.+D_+SE`,:/
MXA;*C.+<_+SE`,:/XA;*C.+4_+SE`,:/XA;*C.+,_+SE`,:/XA;*C.+$_+SE
M,$`MZ2303>(<`(WE&!"-Y10@C>48$(WB%""-XAP`C>+P09_EJO__Z^PQG^4$
M0(_@`S"4YPPPC>7@,9_E#""=Y0,PE.<"$*#A`P"@X1`PC>5=___KR#&?Y0,P
ME.<`4-/EP#&?Y0``5>,#0)3G"P``&GG__^NP(9_E``!0XP(@C^`,`(+E`0``
M&@$`H..9___KJO__ZP``E.7#___K>U?`Y0``E.7`___KSC/0Y0(P@^/.,\#E
M``"4Y;O__^O.,]#E`3"#X\XSP.4<`)WE`R"`X@0`@.('`7#C````FG/__^L`
M`:#A#""-Y8[__^L\,9_E&,"=Y0,PC^`$`(/E`#"<Y1P0G>4`,(#E)#&?Y0P@
MG>4#,(_@!#"`Y1@QG^40X(#B`S"/X``PD^4(,(#E"#&?Y0,PC^`,,(#E`3"@
MXP,`4>$P``#*``!1XP,P@>(0,*#3`S&@P0`0H./@4)_E`Q"`YP`0C>78$)_E
M!5"/X``PH.$!$(_@#`"5Y2C__^L`0%#B`@``&@P`E>5@___K`$"@X;!0G^4%
M4(_@#`"5Y3W__^ND`)_E``"/X-,``.L``%#C#```&@@PE>4``%/C`P``&H@`
MG^4``(_@RP``ZP@`A>5\,)_E`S"/X`@`D^4``%#C````"IL&`.MH,)_E`S"/
MX`P`D^5U___KS_[_ZP0`H.$DT(WB,("]Z`-!G.<!,(/B!$".Y,C__^J4:P$`
M.`$``#0!```$`0``&`$``-AL`0!@;`$`#"T``!1L`0#O+```[&L!`.0(``#`
M:P$`ARH``!PJ``"`:P$`:&L!``"PH.,`X*#C$!"?Y0$0C^`-`*#A#\#`XPS0
MH.$```#K:&@!`!]`+>E(,)_E2""?Y0,PC^`"()/G"""-Y3P@G^4"()/G#""-
MY0`@H.,$((WE+""?Y0(PD^<$((#B`#"-Y0`0D.4(,)WE#`"=Y?7^_^L4T(WB
M!/"=Y#1I`0`4`0``_`````@!```L`)_E+#"?Y0``C^`#,(_@``!3X2`PG^4#
M,(_@'O\O`1@@G^4",)/G``!3XQ[_+P$3_R_A3&H!`$AJ`0#$:`$`$`$``#@`
MG^4X$)_E``"/X`$0C^``$$'@H3^@X4$1@^`D,)_EP1"PX0,PC^`>_R\!&""?
MY0(PD^<``%/C'O\O`1/_+^$(:@$`!&H!`'1H`0`L`0``:#"?Y1!`+>D#,(_@
M`##3Y5Q`G^4``%/C!$"/X!"`O1A0,)_E`S"4YP``4^,"```*1#"?Y0,`G^?*
M_O_KRO__ZS@PG^4#,)3G``!3XP(```HL`)_E``"/X&[^_^L!(*#C(#"?Y0,P
MC^``(,/E$("]Z+AI`0`P:`$`)`$``%!I`0`,`0``E&8``%QI`0`T,)_E-""?
MY0,PC^`",)/G``!3XP<```H00"WI(!"?Y2``G^4!$(_@``"/X*W^_^L00+WH
MNO__ZKG__^JT9P$`*`$``!1I`0`T9@``G#"?Y?!'+>D`4%#B`S"/X`5`H`$@
M```*B""?Y0(PD^<`0)/E``!4XQL```H!D*#A!3"@X0-@H.$!(-/D``!2XST`
M4A/Z__\:!("@X05@1N`(<*#A!*"8Y```6N,*0*`!#0``"@8@H.$%$*#A"@"@
MX5/^_^L``%#C]/__&@8PVN<]`%/C\?__&@1P1^!'<:#A`4"&X@!PB>4$0(K@
M!`"@X?"'O>AD9P$`'`$```=`+>E,()_E3#"?Y0(@C^`#,)+G#1"@X0`PD^4$
M,(WE`#"@X\K__^LP()_E*#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XP``
M``JF_O_K#-"-X@3PG>2X9@$`(`$``)1F`0!S0"WID""?Y9`PG^4"((_@`S"2
MYP!`H.$`,)/E!#"-Y0`PH.,-8*#A=%"?Y050C^`&$*#A!`"@X:S__^L``%#C
M"0``&EP@G^50,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C"@``"H;^_^LX
M,)_E`""=Y0,PE><`,)/E`C&#X`0@D^4``%+C!""#Y/O__QKF___J"-"-XG"`
MO>A49@$`(`$``#1F`0`49@$`'`$``/!'+>E`(9_E0#&?Y0(@C^`#,)+GH-!-
MX@!04.(`,)/EG#"-Y0`PH.,3```*`##5Y0``4^,0```*N/W_ZP!@4.(-```*
M"'&?Y0B!G^4(D9_E!W"/X`B`C^`)D(_@!@"@X=+]_^L`0%#B#0``&@8`H.'I
M_?_K!0"@X2_^_^O<()_ER#"?Y0(@C^`#,)+G`""3Y9PPG>4"(#/@`#"@XR@`
M``I,_O_K$T"$X@<0H.$$`*#AN_W_ZP``4./G__\*"!"@X00`H.&V_?_K``!0
MX^+__PH%`*#A//[_ZP"@H.$$`*#A.?[_ZP``BN`"`(#BOOW_ZP"@H.$$,*#A
M!2"@X0D0H.$H_O_K#1"@X0H`H.$-_O_K`0!PXPH`H.$'```*$#"=Y0\Z`^(!
M"5/C`P``&K/__^L*`*#A#/[_Z\?__^JG_?_K^O__ZJ#0C>+PA[WHI&4!`"`!
M```W)0``,B4``#$E```L90$`$$`MZ8@@G^6(,)_E`B"/X*#03>(#,)+G#1"@
MX0!`H.$`,)/EG#"-Y0`PH./X_?_K``!0XP``H!,)```:$#"=Y0\Z`^(*"E/C
M`0E3$P0``!H"$*#C!`"@X6/]_^L0#V_AH`*@X3`@G^4H,)_E`B"/X`,PDN<`
M()/EG#"=Y0(@,^``,*#C````"OG]_^N@T(WB$("]Z$!D`0`@`0``X&,!`/!/
M+>D!4*#AQ"&?Y<0QG^4"((_@`S"2YQ303>(`,)/E##"-Y0`PH.,`,-'E`&"@
MX3T`4^,!4($"!0"@X>']_^L($(WB`'"@X08`H.'Z_O_KA)&?Y0!`4.()D(_@
M$0``"MC]_^L``%?A)@``B@%`1.(!,-7D``!3XP$PY.7[__\:6"&?Y4PQG^4"
M((_@`S"2YP`@D^4,,)WE`B`SX``PH.-)```*ROW_ZS0QG^4#H)GG`+":Y00Q
MF^<``%/C,P``&B`QG^4"@(3B`S"/X``@D^4(@:#A``!2XRX```H($*#A"P"@
MX1+]_^L``%#C``"*Y>+__PH`,)KE"("#X``PH.,$,`CE"$"-Y08PH.$#`*#A
M`2#3Y```4N,]`%(3^O__&KPPG^4&`$#@`T"9YP)PA^('`(#@")"=Y0"`E.4I
M_?_K``!0XPD!B.?,__\*`#"4Y0@@G>4"(9/G`1#6Y`(PH.$``%'C/0!1$P`0
MPN4!((+B^/__&CT@H.,`(,/E`2#5Y```4N,!(./E^___&KO__^H!0(3BQO__
MZ@$@H.,(`*#A`""#Y0_]_^L`,%#B!#"-Y;+__PH+$*#A""!(X@S]_^L$,)WE
M`#"*Y<G__^H4T(WB\(^]Z)QC`0`@`0``5&,!`"1C`0`<`0``>&0!`!-`+>D\
M0)_E/#"?Y01`C^`#,)3G``"3Y6/]_^LL,)_E+!"?Y0,PE.<!$(_@!#"-Y2`P
MG^4$()WE`S"/X`C0C>(00+WH4OW_ZK1A`0`8`0``,`$``'<A``!I7P``$T`M
MZ4PPG^5,()_E`S"/X`)`D^<``)3E3/W_Z^#__^L``)3E2?W_ZP`@H.,L,)_E
M!""-Y2@0G^4H()_E`S"/X``PC>4"((_@`1"/X++\_^L(T(WB$("]Z%AA`0`8
M`0``@R,``!<A```\#P``<$`MZ3`1G^4P(9_E`MI-XAC03>(!$(_@`B"1YP(Z
MC>(4,(/B`""2Y0`@@^4`(*#CJOS_ZP@AG^4(89_E`B"/X``@C>4`(9_E#$"-
MX@`PH.$&$*#A!`"@X0(@C^"0_/_K`3"`X@8`4^$```":\`#PYP$`<.,,```:
M`#"@X\P`G^6X$)_E``"/X`(JC>(!$)#G%"""X@``D>4`$)+E```QX``0H.,@
M```*'/W_ZP%:C>(04(7B!`"@X0$JH.,%$*#AR_S_ZP!`4.+J__^Z`0"$XI?\
M_^L`,%#BYO__"@4`4^$"```J!""#X`(`5>'>__\Z!0!3X0(``)H$((7@`@!3
MX=G__SH&`%3AU___R@0@H.$#`*#A!1"@X??\_^L`(*#C`#"@X00@P.?3___J
M`P"@X0+:C>(8T(WB<("]Z.1@`0`@`0``V"````$0``"P(```=&`!`*G__^KP
M3RWI`5"@X?`1G^7P(9_E0MU-X@$0C^`TT$WB`$"@X>`!G^4"()'G0CV-X@``
MC^`L,(/B`""2Y0`@@^4`(*#C)?[_ZR\0H.,`8*#A!`"@X7_\_^L``%#C#P``
M"J@!G^4$$*#A``"/X.'^_^N<$9_EC"&?Y0$0C^!"/8WB`B"1YRPP@^(`$)+E
M`""3Y0$0,N``(*#C50``"LK\_^L$`*#AQ?S_ZV@1G^4,`(WE`1"/X`4`H.&Q
M_/_K`'"@X521G^54H9_E5+&?Y0F0C^`*H(_@"["/X```5^/?__\*`"#7Y0``
M4N,)<*`!``!6XPD```H'$*#A!@"@X27\_^L``%#C!```&A@1G^4!$(_@F_S_
MZP!PH.'N___J!P"@X:;\_^L`P*#C``"'X`<00.`!('#E+P!2XQ$```H,,)WE
M`2"#X@$@@N`!"E+CP___JK"`C>($4$CB!S"@X0H@H.$!&J#C!0"@X01`C>4`
ML(WE]OO_ZP$`@.(!"E#C`@``FO``\.<`P,#EY___Z@4`H.$0$(WB:/S_ZP``
M4.,0```:D#`8Y0\Z`^(""5/C#```&@$0H.,%`*#AX?O_ZP``4.,'```:8`"?
MY040H.$``(_@B/[_ZP4`H.$/_/_K`$"@X:+__^I$$)_E``"@XP$0C^#&___J
M!`"@X4+=C>(TT(WB\(^]Z(Q?`0`@`0``E!\``&4?```L7P$`*A\``*\>``#8
M'P``"!\``,X>```!'@``[AT````PH.$!(-/D``!2XQ[_+P$O`%+C`P"@`?G_
M_^H00"WI`$!0X@(```H`,-3E``!3XP,``!K8`)_E``"/X!!`O>CH^__J4/S_
MZP$`0.(``(3@``!4X0`PH.$;```J`"#3Y0$`0.(O`%+C^/__"@,`5.$5```J
M`R"@X0$04N0O`%'C#P``&@$P0^(#`%3A`R"@X0,``"H`$-+E`3!#XB\`4>/X
M__\*!"!"X`(P@N(!"E/C%0``B@$@@N(!"E+C#```FO``\.<",*#AY___Z@,`
M5.'K__\:`##4Y2\`4^,T`)\%``"/`-3__PHL`)_E``"/X-'__^HD,)_E!!"@
MX0,PC^`#`*#AV_O_ZQ"`O>@``*#C$("]Z`\=``!G'```O!P``!A>`0`00"WI
MQ"&?Y<0QG^4"((_@*-!-X@,PDN<-(*#AM!&?Y0`PD^4D,(WE`#"@XP$0C^`*
M,('B*L"!X@+@H.$``)/E!!"3Y0@P@^(#`*[H#`!3X0X@H.'W__\:L##3X7@!
MG^6P,,[A``"/X%_]_^ML`9_E;$&?Y0``C^!;_?_K9`&?Y01`C^```(_@5_W_
MZU@!G^4``(_@5/W_ZU`!G^4``(_@4?W_ZT@!G^4``(_@3OW_ZT`!G^4``(_@
M2_W_ZS@!G^4``(_@2/W_ZP0`H.%&_?_K*`&?Y0``C^!#_?_K(`&?Y0``C^!`
M_?_K&`&?Y0``C^`D_?_K`!!0X@$```H$`*#AYOW_ZP`!G^4``(_@'?W_ZP`0
M4.("```*\`"?Y0``C^#>_?_KZ`"?Y0``C^`5_?_K`!!0XA$```K8`)_E``"/
MX-;]_^O0$)_ET`"?Y0$0C^```(_@T?W_Z\0@G^5P,)_E`B"/X`,PDN<`()/E
M)#"=Y0(@,^``,*#C$@``"KS[_^N@`)_E``"/X/[\_^L`$%#BE`"?%0``CQ#H
M__\:C!"?Y0H@H.,!$(_@$0"-XCO[_^L``%#CXO__&G0`G^4;$(WB``"/X-W_
M_^HHT(WB$("]Z$!<`0`@`0```5H``"(<```;'```31P``!,<```0'```"QP`
M``\<``"X&P```QP```,<``"5&P``]1L``.H;``#A&@``W!L``#`;``#D&P``
M5QL``.Q:`0"0&P``+QL``($;```#&P``$$`MZ4PPG^4#,(_@`#"3Y0$`<^,,
M```:/`"?Y0``C^#*_/_K``!0XP0```H``-#E,`!0XP``4!,!`*`3``"@`Q@P
MG^4#,(_@``"#Y1`PG^4#`)_G$("]Z$Q;`0!O&@``$%L!``1;`0`00"WI=?O_
MZQK[_^L``%#C``"0%1"`O>CW0"WIF'"?Y0!`H.$'<(_@!P"@X:W\_^L`4%#B
M!!"@X0(```H`,-7E``!3XP0``!IP`)_E``"/X`S0C>+P0+WH:/W_ZO;Z_^L`
M`%#C$@``&@0`H.%5^__K`&"@X04`H.%2^__K``"&X`(`@.+7^O_K`&"@X3`P
MG^4P$)_E!""@X0$0C^``4(WE`S"/X#[[_^L&$*#A!P"@X>;__^H,T(WB\("]
MZ&X:``!&&@``0AD``!@:``#P3RWI<!:?Y7`FG^6!W$WB)-!-X@$0C^!DQI_E
M`B"1YX$\C>(23HWB#,"/X``@DN4<((/E`""@XQPP@^(04(SB=#!$XES@1.(`
M8*#A!P"<Z0<`@^@/`+7H#P"NZ`,`E>AH,$3B*,",X@,`CN@'`)SH!P"#Z`P&
MG^4,=I_E``"/X&7\_^L`4%#B!W"/X!0```H`,-7E``!3XQ$```JJ___KZ!6?
MY=0EG^4!$(_@@3R-X@(@D><<,(/B`!"2Y0`@D^4!$#+@`""@XP````H-^__K
M!0"@X8'<C>(DT(WB\$^]Z)SZ_^J2___K`%!0XFB`1`)F```*!0"@X?_Z_^N`
M`*#A`0"`XH3Z_^L`D*#A`("@X7REG^4!4$7B"J"/X`$@]>4``%+C7P``&ER`
M1.($4)CD``!5XPP```H%`*#A-OS_ZP!04.+X__\*`##5Y0``4^/U__\*SOS_
MZP``4./R__\*!0"@X7OZ_^L`4*#A=*!$X@``5>,%```:!(":Y```6.-5```*
M`##8Y0``4^-*```:!0"@X=CZ_^L`H*#A"0"@X=7Z_^L``(K@`:N`X@2@BN(*
M`*#A6/K_ZP"`H.'4-)_EU!2?Y0,PC^``,(WES#2?Y04@H.$#,(_@`1"/X`20
MC>6\^O_K!QV@XP@`H.&G^O_K`0!PXSH``!JA^O_K`#"0Y1$`4^,V```*E"2?
MY904G^4"`)?G`#"-Y0`@EN4(,*#A``"0Y0$0C^!]^O_K`%"@XW04G^5$))_E
M`1"/X($\C>("()'G'#"#X@`0DN4`()/E`1`RX``@H..;__\:!0"@X8'<C>(D
MT(WB\(^]Z.K[_^L`,%#B!0``"@`PT^4``%/C`@``"C/Z_^L`4%#BF/__&@0`
MF.0``%#C\___&@Q4G^4%4(_@DO__Z@@`H.$*$*#AB/K_ZP*`B.*7___J"`"@
MX7/\_^L``%#CJO__"@@`H.$@^O_K`%"@X:3__^H(4*#AJO__Z@@`H.$0$(WB
M;?K_ZP"04.((```*I#.?Y;`3G^4#`)?G`""6Y0@PH.$!$(_@``"0Y4+Z_^O#
M___J`#$4Y0\Z`^(!"5/C\O__&OA0%.5W^O_K``!5X>[__QH`,13E@SN@X:,[
MH.$'#5/CZ?__&@H`H.'P^?_K`%"@X50#G^4``(_@K/O_ZP``4.-A```:`'"6
MY0<`H.%?^O_K`P!0XP"@H.$:``":+!.?Y00`0.(!$(_@``"'X,WY_^L``%#C
M$P``&@0`6N,#```*"J"'X`4P6N4O`%/C#0``&@1@EN4``%;C"@``"@8`H.%*
M^O_K`P!0XP8``)K@$I_E!`!`X@$0C^```(;@N?G_ZP``4.,&<*`!M/[_ZP"@
M4.)U```:"A"@X0<`H.'5^?_K`&!0XG````H"D*#C`##@XQ$@X.,`D(WE!'!$
MXJ/Y_^L&(*#C!Q"@X08`H.$%^O_K!#!4Y0``4^,S```:`S!4Y4,`4^,P```:
M`C!4Y4$`4^,M```:`3!4Y4,`4^,J```:`##4Y4@`4^,G```:`3#4Y44`4^,D
M```:`##@XSD@X.,&`*#A`)"-Y8CY_^LI(*#C!Q"@X08`H.'J^?_K"""@X1`R
MG^40$I_E`S"/X`0PC>4(,I_E`'"-Y0,PC^`!$(_@!0"@X0#Z_^L(`*#A[_G_
MZ^P!G^4%$*#A``"/X!'\_^L%`*#AE?[_ZTW__^H`<);EE?G_ZP`0H.$'`*#A
M#/W_ZP!P4.*7__\:E?__Z@`PH.,`(*#C`#"-Y08`H.$`,*#C8OG_Z_T#`.L`
MD*#A`BF@XP<0H.$&`*#APOG_ZP`@4.(=``#*!@"@X41@1.*W^?_K,'!$X@D0
MH.$&`*#A5`0`ZP>0H.%<L9_E"["/X`<`H.$+$*#A`2#6Y`&@BN+2^?_K%`!:
MXP)PA^+W__\:`#"@XP@P1.4P,9_E,!&?Y0,PC^`$,(WE*#&?Y0@@H.$`D(WE
M`S"/X`$0C^#`___J!Q"@X0D`H.'I`P#KU___Z@01G^4$`9_E`1"/X```C^#1
M^__K-?G_Z_0PG^7T$)_E`S"/X`D`C>CL,)_E"""@X04`H.$#,(_@`1"/X*_Y
M_^O80)_EV&"?Y=APG^4$0(_@!F"/X`=PC^`'':#C!0"@X93Y_^L!`'#CH___
M&H[Y_^L`,)#E$0!3XY___QH;^?_K`9")X@$"C>@$,*#A"""@X080H.$%`*#A
M"'"-Y9?Y_^OL___JS%@!`"`!``#X60$`A!@``%A8`0`X6`$`Q1@``"<8```*
M&```1!<````!``#,%P``J%8!`#87```?%P``<18``.X6``"C%@``AQ8``,`5
M``!4%```'!0``&D4``"3%0``R!0``%P3``#D$P``<Q,``$,5``"'%```#!,`
M`/02``!]%```#Q4``'-`+>DL,I_E+"*?Y0,PC^`"0)/G``"4Y6KY_^L`4*#A
M``"4Y6?Y_^MD,-7E93#`Y0@"G^4``(_@MOK_ZP``4.,%```*`##0Y3$`4^,"
M```:`3#0Y0``4^,````*2_W_ZP``E.57^?_KU!&?Y0,PH.,!(*#C`1"/X`'Y
M_^L`4%#B$```"@``E.5.^?_K##"5Y;`AG^4`$)/E`B"/X/[X_^L,,)7E`#"3
MY0@PD^4!!1/C!```"@``E.5"^?_K##"5Y0`0D^7-^/_K``"4Y3WY_^MT$9_E
M`S"@XP$@H.,!$(_@Y_C_ZP!04.(7```*7`&?Y0``C^"'^O_K`"!0X@0@C>4&
M```*``"4Y2[Y_^L,,)7E!""=Y0`0D^7?^/_K"@``ZN_[_^L`8%#B``"4Y2@`
M``HD^?_K##"5Y08@H.$`$)/EU?C_ZP8`H.$2^?_K``"4Y1SY_^L`4*#A``"4
MY1GY_^OL$)_E`2"@XP$0C^!_^/_KX""?Y0`0H.$"((_@!0"@X<7X_^L``)3E
M#OG_ZP`PH.-E,,#EP`"?Y<!`G^4``(_@7/K_ZP1`C^```%#C"`"$Y0X``!H$
M`)3ES_W_ZP``4.,(`(3E"0``&I0`G^4``(_@<OC_Z_OX_^N(,)_E`S"/X`0@
MD^4,,)7E`""2Y<C__^IT0)_E!QV@XP1`C^`(`)3EX?C_ZP$P@.(1`%#C`0!3
M$P8``)H`,*#A!!"4Y4P`G^4(()3E`!"1Y0``C^!;^/_K"-"-XG"`O>C040$`
M&`$```,2```^$P``'!,``-T2```5$0``4Q(``%@2``!@$```S%$!``H2``"4
M40$`>%$!`,\1``!P0"WI`$"@X8'\_^MY_/_K`%"@X4[]_^L``%#C``!4$W"`
MO0@`,-3E``!3XW"`O0@<$)_E!0"@X0$0C^!M^/_K``!5X7"`O1@$`*#A<$"]
MZ%CZ_^H[$```\$\MZ30KG^4T.Y_E`B"/X%/?3>(#,)+G!""-X@+`H.$`,)/E
M1#&-Y0`PH.-<X(#B'#"`X@00D^0Q'[_F`P!>X000C.3Z__\:0,"@XP(0H.$@
MX)'E-#"1Y00@@N(.,"/@"."1Y0`0D>4.,"/@`3`CX.,_H.$!P%SB/#""Y?+_
M_QK`.I_E!)"=Y1!@D.4(()WE@$"0Z-A`P.$#D(G@!<`DX&X1).`'$`'@`R""
MX`:0B>`.P`S@YYV)X`7`+.`%((+@!!`AX`R0B>`"$('@9\&@X0P@G>5NH2S@
M":`*X`,@@N`0@)WE!"""X&ZA*N#I'8'@`J"*X&DA+.`!(`+@`X"(X.&MBN`4
ML)WE81&@X0P@(N!N@8C@""""X&F!(>`#L(O@"H`(X`S`B^!I@2C@&+"=Y>HM
M@N`,@(C@:L$AX`.PB^`"P`S@XHV(X&F1B^!B(:#A'+"=Y0'`+.`)P(S@:I$B
MX`.PB^`(D`G@`1"+X&J1*>`@L)WEZ,V,X`&0B>!H$2+@`["+X`P0`>#LG8G@
M:J&+X&S!H.$DL)WE`A`AX`H0@>!HH2S@`["+X`F@"N`"((O@:*$JX"BPG>7I
M'8'@`J"*X&DA+.`#L(O@`2`"X.&MBN!H@8O@81&@X2RPG>4,("+@""""X&F!
M(>`#L(O@"H`(X`S`B^!I@2C@,+"=Y>HM@N`,@(C@:L$AX`.PB^`"P`S@:9&+
MX`'`+.#BC8C@"<",X&(AH.$TD)WE:K$BX`.0B>`(L`O@`1")X&JQ*^`XD)WE
MZ,V,X`&PB^!H$2+@`Y")X`P0`>#LO8O@:J&)X&S!H.$\D)WE`A`AX`H0@>!H
MH2S@`Y")X`N@"N`"((G@:*$JX$"0G>7K'8'@`J"*X&LA+.`#D(G@`2`"X.&M
MBN!H@8G@81&@X420G>4,("+@""""X&N!(>`#D(G@"H`(X&N!*.`,P(G@#,"(
MX$B`G>7J+8+@:I$AX`.`B.`"D`G@:[&(X`&0*>#BS8S@"Y")X&(AH.%,L)WE
M:H$BX`.PB^`,@`C@:H$HX`$0B^!0L)WE[)V)X`$0B.!L@2+@`S"+X`F`".!J
MH8/@`H`HX!PXG^4*@(C@5*"=Y>D=@>`#H(K@:9&@X0(@BN!LH2G@`:`JX`H@
M@N!8H)WEX8V(X`.@BN!LP8K@8:$IX`B@*N`*P(S@7*"=Y>@M@N`#H(K@:(&@
MX0F0BN!AH2C@`J`JX`J0B>!@H)WEXLV,X`.@BN!A$8K@8J$HX`R@*N`*$('@
M9*"=Y>R=B>`#H(K@;,&@X0B`BN!BH2S@":`JX`J`B.!HH)WE;+"=Y0.@BN#I
M'8'@8B&*X&FA+.#AC8C@`:`JX`.PB^!A$:#A#,"+X&FQ(>`(L"O@"[",X'#`
MG>4*((+@`\",X'2@G>7H+8+@:<&,X&B1(>#BO8O@`I`IX`.@BN!B(:#A`1"*
MX&BA(N`+H"K@"J"!X'@0G>4)P(S@`Q"!X'R0G>7KS8S@:!&!X&N!(N#LK8K@
M#(`HX`.0B>!LP:#A`B")X&N1+.`*D"G@"9""X(`@G>4($('@`R""X(2`G>7J
M'8'@:R&"X&JQ+.#AG8G@`;`KX`.`B.!A$:#A#,"(X&J!(>`)@"C@"(",X(C`
MG>4+((+@`\",X(RPG>7I+8+@:L&,X&FA(>#BC8C@`J`JX`.PB^!B(:#A`1"+
MX&FQ(N`(L"O@"["!X)`0G>4*P(S@`Q"!X.C-C.!I$8'@:)$BX`R0*>`)$('@
ME)"=Y>R]B^`#D(G@;,&@X0(@B>!HD2S@"Y`IX`F0@N"8()WEG*"=Y0,@@N#K
M'8'@:"&"X&N!+.#AG8G@`8`HX`.@BN!A$:#A#*"*X&O!(>`)P"S@#*"*X*#`
MG>4(((+@`\",X.DM@N!KP8S@:;$AX.*MBN`"L"O@8B&@X6F!@N%I,0+@"H`(
MX`O`C.`#@(CAI+"=Y:0UG^7JS8S@`["+X`$0B^`!@(C@:A&"X6JQ`N`,$`'@
M"Q"!X:BPG>7LC8C@`["+X&S!H.%ID8O@"1"!X&J1C.%JL0S@")`)X`N0B>&L
ML)WEZ!V!X`.PB^`"((O@`I")X&@AC.%HL0S@`2`"X`L@@N&PL)WEX9V)X`.P
MB^!A$:#A:J&+X`H@@N!HH8'A:+$!X`F@"N`+H(KAM+"=Y>DM@N`#L(O@#,"+
MX`R@BN!IP8'A:;$!X`+`#.`+P(SAN+"=Y>*MBN`#L(O@8B&@X6B!B^`(P(S@
M:8&"X6FQ`N`*@`C@"X"(X;RPG>7JS8S@`["+X`$0B^`!@(C@:A&"X6JQ`N`,
M$`'@"Q"!X<"PG>7LC8C@`["+X&S!H.%ID8O@"1"!X&J1C.%JL0S@")`)X`N0
MB>'$L)WEZ!V!X`.PB^`"((O@`I")X&@AC.%HL0S@`2`"X`L@@N'(L)WEX9V)
MX`.PB^!A$:#A:J&+X&BQ@>$*((+@";`+X&BA`>`*L(OAS*"=Y>DM@N`#H(K@
M#,"*X`RPB^!IP8'A::$!X`+`#.`*P(SAT*"=Y>*]B^`#H(K@8B&@X6B!BN!I
MH8+A",",X`N@"N!I@0+@"*"*X=2`G>7KS8S@`X"(X`$0B.`!H(K@:Q&"X6N!
M`N`,$`'@"!"!X=B`G>7LK8K@`X"(X&S!H.%ID8C@"1"!X&N1C.%K@0S@"I`)
MX`B0B>'<@)WEZAV!X`.`B.`"((C@`I")X&HAC.%J@0S@`2`"X`@@@N'@@)WE
MX9V)X`.`B.!A$:#A:[&(X`L@@N!JL8'A:H$!X`FP"^`(L(OAY("=Y>DM@N`#
M@(C@#,"(X&F!@>$,L(O@`H`(X&G!`>`,@(CAZ,"=Y>*]B^`#P(S@8B&@X6JA
MC.`*@(C@::&"X6G!`N`+H`K@#*"*X>S`G>7KC8C@`\",X`$0C.!KP8+A`:"*
MX`C`#.!K$0+@`<",X?`0G>7HK8K@`S"!X&F1@^`)P(S@Q#*?Y?20G>5H@:#A
M`Y")X`(@B>#X$)WE:Y$HX`J0*>`)D(+@`Q"!X/P@G>7JS8S@:Q&!X&JQ*.#L
MG8G@#+`KX`,@@N!LP:#A"(""X&HA+.`)("+@`H"(X``AG>4+$('@`R""X`2Q
MG>7I'8'@:B&"X&FA+.#AC8C@`:`JX`.PB^!A$:#A#,"+X&FQ(>`(L"O@"[",
MX`C!G>4*((+@`\",X`RAG>7H+8+@:<&,X&B1(>#BO8O@`I`IX`.@BN!B(:#A
M`1"*X&BA(N`+H"K@"J"!X!`1G>4)P(S@`Q"!X.O-C.!H$8'@:X$BX`R`*.`(
M$('@%(&=Y>RMBN`#@(C@;,&@X0(@B.!K@2S@"H`HX`B`@N`8(9WE')&=Y0,@
M@N#J'8'@:R&"X&JQ+.#AC8C@`;`KX`.0B>!A$:#A#,")X&J1(>`(D"G@"9",
MX"#!G>4+((+@`\",X"2QG>7H+8+@:L&,X&BA(>#BG8G@`["+X`*@*N!B(:#A
M`1"+X&BQ(N`)L"O@"["!X"@1G>4*P(S@`Q"!X.G-C.!H$8'@:8$BX`R`*.`(
M$('@+(&=Y>R]B^`#@(C@;,&@X0(@B.!I@2S@"X`HX`B`@N`P(9WEZQV!X`,@
M@N!I(8+@:Y$LX`&0*>`)((+@-)&=Y>&-B.`#D(G@81&@X0S`B>!KD2'@")`I
MX`G`C.`XD9WEZ"V"X`.0B>!KL8G@:)$AX`*0*>`)L(O@/)&=Y>+-C.`#D(G@
M8B&@X0$0B>!HD2+@#)`IX`D0@>!`D9WE[+V+X`,PB>`'<(/@:(&'X&QQ(N`+
M<"?@`B"&X.L=@>`0((#E!X"(X&`@G^7AC8C@1#"?Y0$0CN!KL83@;,&%X`(@
MC^``@(#E!!"`Y0BP@.4,P(#E`S"2YP`@D^5$,9WE`B`SX``PH.,````*__7_
MZU/?C>+PC[WH!$\!`"`!``"9>8):H>O9;MR\&X_6P6+*"$0!`!!`+>E@`*#C
M>/7_ZR@0G^4H()_E*,"?Y2C@G^4&4(#H)""?Y1`@@.4`(*#C%""`Y1@@@.5<
M((#E$("]Z`$C16>)J\WO_MRZF'94,A#PX=+#\$$MZ0)@H.$4,)#E@B&@X0(P
MD^`8()`E%#"`Y0$@@B(8((`E&#"0Y0!0H.&F/H/@&#"`Y5PPD.4<<(#B``!3
MXQD```I`0&/B!`!6X0,`A^`&0*"Q`0!0X0,``"H$,(#@`P!1X0```"KP`/#G
M`0!0X02`@>`!``":"`!0X?G__SH$(*#AM_7_ZUPPE>4#,(3@0`!3XUPPA>7P
M@;T8!0"@X>O\_^L($*#A!&!&X%R`A>(_`%;C#@``R@<`4>$"``":!C"'X`,`
M4>'F__\Z!P!1X0(``"H&,('@`P!7X>'__SH&(*#A!P"@X9[U_^M<8(7E\(&]
MZ`<`4>$!``":"`!1X=C__SH!`%?A0#"!X@$``)H#`%?AT___.@%`H.$'(*#A
M!!"4Y`,`5.$$$(+D^___&@4`H.'&_/_K0&!&X@00H.':___J\$$MZ1R`@>(4
M,)'E&&"1Y0%`H.%_$.#C,W^_YJ,QH.$_,`/B`2"#XC@`4N,`4*#A`Q#(YP(`
MB.``$*#3-F^_YC@@8M('``#:`!"@XT`@8N+X]/_K!`"@X:S\_^LX(*#C`!"@
MXP@`H.'R]/_K!`"@X?1EQ.&E_/_K`S#4Y00`H.$`,,7ELC#4X0$PQ>4`,)3E
M(S2@X0(PQ>4`,)3E`S#%Y0<PU.4$,,7EMC#4X04PQ>4$,)3E(S2@X08PQ>4$
M,)3E!S#%Y0LPU.4(,,7ENC#4X0DPQ>4(,)3E(S2@X0HPQ>4(,)3E"S#%Y0\P
MU.4,,,7EOC#4X0TPQ>4,,)3E(S2@X0XPQ>4,,)3E#S#%Y1,PU.40,,7ELC'4
MX1$PQ>40,)3E(S2@X1(PQ>40,)3E$S#%Y?!!O>@H]?_J`4`MZ0%`O>@>_R_A
M.P```#X````+````/@```!`````^````)0```#X````S````/@````,````^
M````!@```#X````4````/@````X````^````#0```#X````D````/@```!(`
M```^````)P```#X````"````/@```!@````^````"0```#X````*````/@``
M````````````+W1M<`!005)?5$U01$E2`%1%35!$25(`5$U0`%5315(`55-%
M4DY!344`+BX`)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN
M=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S`&5X90!005)?5$5-4`!0
M05)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$52
M3$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%2
M7T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?
M5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#
M3$5!3CT`,0!,1%],24)205)97U!!5$@`4UE35$5-`"4P,G@`)7,E<R5S)7,`
M<&%R+0`E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@
M;W!E<F%T:6]N*0H`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP
M+25U)7,`)7,E<W1E;7`M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ
M5D524TE/3@`Q+C`U,@!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R
M>0`E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*`"UE`"TM`&5V86P@)V5X96,@+W5S<B]B
M:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG
M('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?
M34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L
M94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@
M1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P
M87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@
M*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?
M=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2![
M"FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A8
M6%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I
M+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N
M86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ
M.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G
M"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E
M<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*
M8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@
M(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*
M;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M
M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L
M<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/
M3U0["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["F5V86P@>PI?<&%R7VEN
M:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#
M;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G
M.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\
M3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H
M)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R
M;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D
M871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P
M96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64@;W(@;&%S=#L*;7D@)&)U9CL*
M;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@
M*B`Q,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I
M>F4I('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE
M("4@)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D
M;3L*?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4[
M"GT*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K(%]&2"P@)&UA9VEC
M7W!O<RP@,#L*<F5A9"!?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H
M*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?
M34%'24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA
M9VEC7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@
M/"`P.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D
M8G5F+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB
M+"`D8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E
M7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*
M?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN
M960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S
M*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D
M9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M
M97T@/0HD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L
M"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&
M2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@
M)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D
M=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]
M(&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M
M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ
M1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@
M;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN
M;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P
M+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A
M=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@
M;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E
M860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S
M=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2([
M"GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@
M24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R
M97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R
M("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<
M+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F
M:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP
M;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL
M87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II
M<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U
M:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P
M;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI
M('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS
M=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V
M97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U
M<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI
M9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY
M($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM
M*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=)
M)RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG
M*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H
M:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T
M(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G
M.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L
M<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@
M)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@
M;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@
M>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?
M=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM
M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#
M86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)
M3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI
M=F4@(B1P87(B73L*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]
M?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A
M(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#
M86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D
M("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL
M95T@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*
M0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O
M=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH
M*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A
M;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*
M<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A
M7W!O<RD@>PIR96%D(%]&2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@
M>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D
M14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E
M;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C
M:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD
M:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;
M)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B
M7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD
M;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G
M('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP
M<FEN="@D;&]A9&5R*3L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC
M*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$
M4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\
M?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`
M1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM
M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@
M("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N
M86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*
M?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^
M(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME
M>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO
M*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D
M9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*
M;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT
M(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ
M<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI
M('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O
M(#T@=6YD968["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X[
M"F-L;W-E("1F:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O
M;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE
M;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z
M.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET
M=&5N(&%S("(D;F%M92)=*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE
M*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA
M;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H
M,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE
M*"1F:"D["F-L;W-E("1F:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E
M<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*
M)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@
M=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR
M97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI[
M"G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD
M;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D
M;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z
M:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU
M;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`[
M"B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D
M14Y6>U!!4E]414U0?2)=*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI
M('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@
M)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^
M:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.
M86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB
M+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T
M7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I
M;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E
M<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H
M*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET
M(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO
M=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA
M;64B72D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE
M*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*
M?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*
M9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A
M<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G
M<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!
M4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E
M>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ
M)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U
M:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I
M8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#
M87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER
M92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P
M96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E
M($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E
M<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A
M='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I
M<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V
M86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@
M<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q
M=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![
M(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@
M)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@
M5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@
M>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@
M+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W
M=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F
M:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS
M,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E
M<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%
M4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE
M(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E
M;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR
M87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M
M92(Z("0A73L*<V5E:R`D9F@L("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L
M("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@
M+34X+"`R.PIR96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L
M<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$[
M"FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@
M(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O
M9VYA;64B.B`D(5T["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*
M)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*
M96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP
M9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@
M/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S
M+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M
M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D
M9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE
M(&]R(&1I92!Q<5M#86XG="!W<FET92`B)'1E;7!N86UE(CH@)"%=.PIP<FEN
M="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M
M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U
M;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN
M86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM0
M05)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO
M*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D
M14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]4
M14U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R
M:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@
M*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N
M9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X
M97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O
M;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES
M=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T[
M"B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M
M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE
M?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@
M/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE
M(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H
M9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F
M:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D
M8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#
M;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV
M('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U
M<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R
M("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%
M("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U0
M1$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D
M14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/
M0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L
M971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!
M4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L
M96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]
M("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@
M;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@
M)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B
M(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D
M969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E
M>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R
M8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E
M(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP
M;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R
M;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O
M<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%
M.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%
M.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$
M7U\*`'!E<FQX<VDN8P!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M(```````.P```#X````+````/@```!`````^````)0```#X````S````/@``
M``,````^````!@```#X````4````/@````X````^````#0```#X````D````
M/@```!(````^````)P```#X````"````/@```!@````^````"0```#X````*
M````/@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````%P``=!8```$````H`P``
M`0```#,#```/````?P0```P````,$```#0```-0]```9````S'T!`!L````$
M````&@```-!]`0`<````!````/7^_V\L`0``!0```*0(```&````%`(```H`
M``"=!```"P```!`````5``````````,```#$?@$``@```.`!```4````$0``
M`!<````L#@``$0```$0-```2````Z````!,````(````&`````````#[__]O
M`0``"/K__V\0````````````````````````````````````````````````
M`````````-1]`0```````````!@0```8$```&!```!@0```8$```&!```!@0
M```8$```&!```!@0```8$```&!```!@0```8$```&!```!@0```8$```&!``
M`!@0```8$```&!```!@0```8$```&!```!@0```8$```&!```!@0```8$```
M&!```!@0```8$```&!```!@0```8$```&!```!@0```8$```&!```!@0```8
M$```&!```!@0```8$```&!```!@0```8$```&!```!@0```8$```&!```!@0
M```8$```&!```!@0```8$```&!```!@0```8$```&!```/P2````````````
M`-0]``````````````P0````````````````````````````````````````
M````````````@`$`_____W`^``";/@```````'4^``!U/P``@#X``(<_``"(
M/@```````(P^``"1/@```````"9!``!'0T,Z("A!;'!I;F4@,3`N,RXQ7V=I
M=#(P,C$P.3(Q*2`Q,"XS+C$@,C`R,3`Y,C$`03(```!A96%B:0`!*`````4V
M6DL`!@<(`0D!"@(2!!,!%`$5`1<#&`$:`AP!'@0B`40!`"YS:'-T<G1A8@`N
M:6YT97)P`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;"YD>6X`+G)E
M;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+FEN
M:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S
M`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````````````````````
M````````````````````````````````"P````$````"````%`$``!0!```8
M```````````````!`````````!,```#V__]O`@```"P!```L`0``Z`````,`
M````````!`````0````=````"P````(````4`@``%`(``)`&```$`````P``
M``0````0````)0````,````"````I`@``*0(``"=!``````````````!````
M`````"T````)`````@```$0-``!$#0``Z`````,`````````!`````@````V
M````"0```$(````L#@``+`X``.`!```#````$`````0````(````/P````$`
M```&````#!````P0```,```````````````$`````````#H````!````!@``
M`!@0```8$```Y`(`````````````!`````0```!%`````0````8```#\$@``
M_!(``-@J``````````````0`````````2P````$````&````U#T``-0]```,
M```````````````$`````````%$````!`````@```.`]``#@/0``A#\`````
M````````!`````````!9`````0````(```!D?0``9'T```0`````````````
M``0`````````8P````X````#````S'T!`,Q]```$```````````````$````
M!````&\````/`````P```-!]`0#0?0``!```````````````!`````0```![
M````!@````,```#4?0$`U'T``/`````$``````````0````(````A`````$`
M```#````Q'X!`,1^```\`0`````````````$````!````(D````!`````P``
M``"``0``@```/```````````````!`````````"/````"`````,````\@`$`
M/(```"P0``````````````0`````````E`````$````P`````````#R````Q
M```````````````!`````0```)T````#``!P``````````!M@```,P``````
M`````````0`````````!`````P``````````````H(```*T`````````````
)``$`````````
